.. _examples:


Create a DataCube
=================
   .. literalinclude:: ../../../examples/00_creating_a_DataCube/00_example.py
      :language: python
      :linenos:

Plot DataCube
=============

   .. literalinclude:: ../../../examples/01_plot_DataCube/01_example.py
      :language: python
      :linenos:

Use DataCube Methods
====================

   .. literalinclude:: ../../../examples/02_use_DataCube_methods/02_example.py
      :language: python
      :linenos:

Create Template
===============

   .. literalinclude:: ../../../examples/03_create_Templates/03_example.py
      :language: python
      :linenos:

Use Template
============

   .. literalinclude:: ../../../examples/04_use_Templates/04_example.py
      :language: python
      :linenos:

Read & Write Data
=================

   .. literalinclude:: ../../../examples/05_read_write/05_csv_example.py
      :language: python
      :linenos:

Plot Surface
============

   .. literalinclude:: ../../../examples/06_plot_surface/06_example.py
      :language: python
      :linenos: